/********************************************************************************
** Form generated from reading UI file 'codegenselectpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CODEGENSELECTPAGE_H
#define UI_CODEGENSELECTPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CodeGenSelectPage
{
public:
    QHBoxLayout *horizontalLayout;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QLabel *ui_labelListAvailable;
    QListWidget *ui_listAvailable;
    QVBoxLayout *vboxLayout1;
    QSpacerItem *spacerItem;
    QPushButton *ui_addButton;
    QSpacerItem *spacerItem1;
    QPushButton *ui_removeButton;
    QSpacerItem *spacerItem2;
    QVBoxLayout *vboxLayout2;
    QLabel *ui_labelListSelected;
    QListWidget *ui_listSelected;

    void setupUi(QWidget *CodeGenSelectPage)
    {
        if (CodeGenSelectPage->objectName().isEmpty())
            CodeGenSelectPage->setObjectName("CodeGenSelectPage");
        CodeGenSelectPage->resize(642, 300);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CodeGenSelectPage->sizePolicy().hasHeightForWidth());
        CodeGenSelectPage->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(CodeGenSelectPage);
        horizontalLayout->setObjectName("horizontalLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, -1, -1, -1);
        ui_labelListAvailable = new QLabel(CodeGenSelectPage);
        ui_labelListAvailable->setObjectName("ui_labelListAvailable");

        vboxLayout->addWidget(ui_labelListAvailable);

        ui_listAvailable = new QListWidget(CodeGenSelectPage);
        ui_listAvailable->setObjectName("ui_listAvailable");
        ui_listAvailable->setAlternatingRowColors(true);
        ui_listAvailable->setSelectionMode(QAbstractItemView::ExtendedSelection);
        ui_listAvailable->setSortingEnabled(true);

        vboxLayout->addWidget(ui_listAvailable);


        hboxLayout->addLayout(vboxLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        spacerItem = new QSpacerItem(20, 71, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem);

        ui_addButton = new QPushButton(CodeGenSelectPage);
        ui_addButton->setObjectName("ui_addButton");
        QIcon icon;
        icon.addFile(QString::fromUtf8("../../../../../../.."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        ui_addButton->setIcon(icon);

        vboxLayout1->addWidget(ui_addButton);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout1->addItem(spacerItem1);

        ui_removeButton = new QPushButton(CodeGenSelectPage);
        ui_removeButton->setObjectName("ui_removeButton");
        ui_removeButton->setIcon(icon);

        vboxLayout1->addWidget(ui_removeButton);

        spacerItem2 = new QSpacerItem(20, 51, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem2);


        hboxLayout->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(0, -1, -1, -1);
        ui_labelListSelected = new QLabel(CodeGenSelectPage);
        ui_labelListSelected->setObjectName("ui_labelListSelected");

        vboxLayout2->addWidget(ui_labelListSelected);

        ui_listSelected = new QListWidget(CodeGenSelectPage);
        ui_listSelected->setObjectName("ui_listSelected");
        ui_listSelected->setAlternatingRowColors(true);
        ui_listSelected->setSelectionMode(QAbstractItemView::ExtendedSelection);
        ui_listSelected->setSortingEnabled(true);

        vboxLayout2->addWidget(ui_listSelected);


        hboxLayout->addLayout(vboxLayout2);


        horizontalLayout->addLayout(hboxLayout);


        retranslateUi(CodeGenSelectPage);

        QMetaObject::connectSlotsByName(CodeGenSelectPage);
    } // setupUi

    void retranslateUi(QWidget *CodeGenSelectPage)
    {
        CodeGenSelectPage->setWindowTitle(tr2i18n("Code Generation Selection", nullptr));
        ui_labelListAvailable->setText(tr2i18n("Classes Available", nullptr));
#if QT_CONFIG(tooltip)
        ui_addButton->setToolTip(tr2i18n("Add class for code generation", nullptr));
#endif // QT_CONFIG(tooltip)
        ui_addButton->setText(tr2i18n("Add >>", nullptr));
#if QT_CONFIG(tooltip)
        ui_removeButton->setToolTip(tr2i18n("Remove class from Code Generation", nullptr));
#endif // QT_CONFIG(tooltip)
        ui_removeButton->setText(tr2i18n("<< Remove", nullptr));
        ui_labelListSelected->setText(tr2i18n("Classes Selected", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CodeGenSelectPage: public Ui_CodeGenSelectPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CODEGENSELECTPAGE_H

