/****************************************************************************
** Meta object code from reading C++ file 'listpopupmenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.90/umbrello/menus/listpopupmenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'listpopupmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ListPopupMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto ListPopupMenu::qt_create_metaobjectdata<qt_meta_tag_ZN13ListPopupMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ListPopupMenu",
        "MenuType",
        "mt_Model",
        "mt_Activity_Diagram",
        "mt_Class_Diagram",
        "mt_Collaboration_Diagram",
        "mt_Component_Diagram",
        "mt_Deployment_Diagram",
        "mt_EntityRelationship_Diagram",
        "mt_Sequence_Diagram",
        "mt_State_Diagram",
        "mt_UseCase_Diagram",
        "mt_Logical_Folder",
        "mt_UseCase_Folder",
        "mt_Component_Folder",
        "mt_Deployment_Folder",
        "mt_EntityRelationship_Folder",
        "mt_Accept_Signal",
        "mt_Accept_Time_Event",
        "mt_Activity",
        "mt_Activity_Transition",
        "mt_Actor",
        "mt_Artifact",
        "mt_Attribute",
        "mt_Branch",
        "mt_Category",
        "mt_CheckConstraint",
        "mt_Choice",
        "mt_Class",
        "mt_CombinedState",
        "mt_Component",
        "mt_Datatype",
        "mt_DeepHistory",
        "mt_DisjointSpecialisation",
        "mt_EditCombinedState",
        "mt_End_Activity",
        "mt_End_State",
        "mt_Entity",
        "mt_EntityAttribute",
        "mt_Enum",
        "mt_EnumLiteral",
        "mt_Exception",
        "mt_FloatText",
        "mt_Final_Activity",
        "mt_ForeignKeyConstraint",
        "mt_Fork",
        "mt_GoToStateDiagram",
        "mt_Initial_Activity",
        "mt_Initial_State",
        "mt_Invoke_Activity",
        "mt_Instance",
        "mt_InstanceAttribute",
        "mt_Interface",
        "mt_InterfaceComponent",
        "mt_InterfaceProvided",
        "mt_InterfaceRequired",
        "mt_Junction",
        "mt_MessageAsynchronous",
        "mt_MessageCreation",
        "mt_MessageDestroy",
        "mt_MessageFound",
        "mt_MessageLost",
        "mt_MessageSynchronous",
        "mt_Node",
        "mt_Note",
        "mt_Object",
        "mt_Object_Node",
        "mt_Operation",
        "mt_OverlappingSpecialisation",
        "mt_Package",
        "mt_Param_Activity",
        "mt_Pin",
        "mt_Port",
        "mt_PrePostCondition",
        "mt_PrimaryKeyConstraint",
        "mt_Region",
        "mt_SelectStateDiagram",
        "mt_Send_Signal",
        "mt_ShallowHistory",
        "mt_State",
        "mt_StateFork",
        "mt_StateJoin",
        "mt_StateTransition",
        "mt_Subsystem",
        "mt_Template",
        "mt_Union",
        "mt_UniqueConstraint",
        "mt_UseCase",
        "mt_New_Activity",
        "mt_New_Attribute",
        "mt_New_EntityAttribute",
        "mt_New_EnumLiteral",
        "mt_New_InstanceAttribute",
        "mt_New_Operation",
        "mt_New_Parameter",
        "mt_New_Template",
        "mt_RemoveStateDiagram",
        "mt_ReturnToClass",
        "mt_ReturnToCombinedState",
        "mt_Hide_Attribute_Signature_Selection",
        "mt_Hide_Attributes_Selection",
        "mt_Hide_Destruction_Box",
        "mt_Hide_NonPublic_Selection",
        "mt_Hide_Operation_Signature_Selection",
        "mt_Hide_Operations_Selection",
        "mt_Hide_Packages_Selection",
        "mt_Hide_Stereotypes_Selection",
        "mt_Hide_Visibility_Selection",
        "mt_Show_Attribute_Signature",
        "mt_Show_Attribute_Signature_Selection",
        "mt_Show_Attributes_Selection",
        "mt_Show_Attributes",
        "mt_Show_Destruction_Box",
        "mt_Show_Documentation",
        "mt_Show_NonPublic_Selection",
        "mt_Show_Operation_Signature",
        "mt_Show_Operation_Signature_Selection",
        "mt_Show_Operations_Selection",
        "mt_Show_Operations",
        "mt_Show_Packages",
        "mt_Show_Packages_Selection",
        "mt_Show_Public_Only",
        "mt_Show_Stereotypes",
        "mt_Show_Stereotypes_Selection",
        "mt_Show_Visibility_Selection",
        "mt_Visibility",
        "mt_DrawAsCircle",
        "mt_ChangeToClass",
        "mt_ChangeToInterface",
        "mt_ChangeToPackage",
        "mt_Open_File",
        "mt_Rename_Object",
        "mt_Select_Operation",
        "mt_Properties",
        "mt_Rename",
        "mt_NameAsTooltip",
        "mt_Show",
        "mt_Delete",
        "mt_Export_Image",
        "mt_Import_Class",
        "mt_Import_Project",
        "mt_Cut",
        "mt_Copy",
        "mt_Paste",
        "mt_Clear",
        "mt_Redo",
        "mt_Undo",
        "mt_Reset_Label_Positions",
        "mt_Line_Color",
        "mt_Line_Color_Selection",
        "mt_Fill_Color",
        "mt_Fill_Color_Selection",
        "mt_Use_Fill_Color",
        "mt_Set_Use_Fill_Color_Selection",
        "mt_Unset_Use_Fill_Color_Selection",
        "mt_Rename_MultiA",
        "mt_Rename_MultiB",
        "mt_Rename_Name",
        "mt_Rename_RoleAName",
        "mt_Rename_RoleBName",
        "mt_Change_Font",
        "mt_Change_Font_Selection",
        "mt_SnapToGrid",
        "mt_SnapComponentSizeToGrid",
        "mt_ShowDocumentationIndicator",
        "mt_ShowSnapGrid",
        "mt_AutoResize",
        "mt_Resize",
        "mt_Up",
        "mt_Down",
        "mt_FlipHorizontal",
        "mt_FlipVertical",
        "mt_Add_Point",
        "mt_Delete_Point",
        "mt_Auto_Layout_Spline",
        "mt_Expand_All",
        "mt_Collapse_All",
        "mt_Refactoring",
        "mt_ViewCode",
        "mt_Clone",
        "mt_Externalize_Folder",
        "mt_Internalize_Folder",
        "mt_AddInteractionOperand",
        "mt_Apply_Layout",
        "mt_Apply_Layout1",
        "mt_Apply_Layout2",
        "mt_Apply_Layout3",
        "mt_Apply_Layout4",
        "mt_Apply_Layout5",
        "mt_Apply_Layout6",
        "mt_Apply_Layout7",
        "mt_Apply_Layout8",
        "mt_Apply_Layout9",
        "mt_LayoutDirect",
        "mt_LayoutSpline",
        "mt_LayoutOrthogonal",
        "mt_LayoutPolyline",
        "mt_Align_Right",
        "mt_Align_Left",
        "mt_Align_Top",
        "mt_Align_Bottom",
        "mt_Align_VerticalMiddle",
        "mt_Align_HorizontalMiddle",
        "mt_Align_VerticalDistribute",
        "mt_Align_HorizontalDistribute",
        "mt_Import_from_File",
        "mt_Remove",
        "mt_Undefined",
        "DataType",
        "dt_MenuPointer",
        "dt_ApplyLayout"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MenuType'
        QtMocHelpers::EnumData<enum MenuType>(1, 1, QMC::EnumFlags{}).add({
            {    2, MenuType::mt_Model },
            {    3, MenuType::mt_Activity_Diagram },
            {    4, MenuType::mt_Class_Diagram },
            {    5, MenuType::mt_Collaboration_Diagram },
            {    6, MenuType::mt_Component_Diagram },
            {    7, MenuType::mt_Deployment_Diagram },
            {    8, MenuType::mt_EntityRelationship_Diagram },
            {    9, MenuType::mt_Sequence_Diagram },
            {   10, MenuType::mt_State_Diagram },
            {   11, MenuType::mt_UseCase_Diagram },
            {   12, MenuType::mt_Logical_Folder },
            {   13, MenuType::mt_UseCase_Folder },
            {   14, MenuType::mt_Component_Folder },
            {   15, MenuType::mt_Deployment_Folder },
            {   16, MenuType::mt_EntityRelationship_Folder },
            {   17, MenuType::mt_Accept_Signal },
            {   18, MenuType::mt_Accept_Time_Event },
            {   19, MenuType::mt_Activity },
            {   20, MenuType::mt_Activity_Transition },
            {   21, MenuType::mt_Actor },
            {   22, MenuType::mt_Artifact },
            {   23, MenuType::mt_Attribute },
            {   24, MenuType::mt_Branch },
            {   25, MenuType::mt_Category },
            {   26, MenuType::mt_CheckConstraint },
            {   27, MenuType::mt_Choice },
            {   28, MenuType::mt_Class },
            {   29, MenuType::mt_CombinedState },
            {   30, MenuType::mt_Component },
            {   31, MenuType::mt_Datatype },
            {   32, MenuType::mt_DeepHistory },
            {   33, MenuType::mt_DisjointSpecialisation },
            {   34, MenuType::mt_EditCombinedState },
            {   35, MenuType::mt_End_Activity },
            {   36, MenuType::mt_End_State },
            {   37, MenuType::mt_Entity },
            {   38, MenuType::mt_EntityAttribute },
            {   39, MenuType::mt_Enum },
            {   40, MenuType::mt_EnumLiteral },
            {   41, MenuType::mt_Exception },
            {   42, MenuType::mt_FloatText },
            {   43, MenuType::mt_Final_Activity },
            {   44, MenuType::mt_ForeignKeyConstraint },
            {   45, MenuType::mt_Fork },
            {   46, MenuType::mt_GoToStateDiagram },
            {   47, MenuType::mt_Initial_Activity },
            {   48, MenuType::mt_Initial_State },
            {   49, MenuType::mt_Invoke_Activity },
            {   50, MenuType::mt_Instance },
            {   51, MenuType::mt_InstanceAttribute },
            {   52, MenuType::mt_Interface },
            {   53, MenuType::mt_InterfaceComponent },
            {   54, MenuType::mt_InterfaceProvided },
            {   55, MenuType::mt_InterfaceRequired },
            {   56, MenuType::mt_Junction },
            {   57, MenuType::mt_MessageAsynchronous },
            {   58, MenuType::mt_MessageCreation },
            {   59, MenuType::mt_MessageDestroy },
            {   60, MenuType::mt_MessageFound },
            {   61, MenuType::mt_MessageLost },
            {   62, MenuType::mt_MessageSynchronous },
            {   63, MenuType::mt_Node },
            {   64, MenuType::mt_Note },
            {   65, MenuType::mt_Object },
            {   66, MenuType::mt_Object_Node },
            {   67, MenuType::mt_Operation },
            {   68, MenuType::mt_OverlappingSpecialisation },
            {   69, MenuType::mt_Package },
            {   70, MenuType::mt_Param_Activity },
            {   71, MenuType::mt_Pin },
            {   72, MenuType::mt_Port },
            {   73, MenuType::mt_PrePostCondition },
            {   74, MenuType::mt_PrimaryKeyConstraint },
            {   75, MenuType::mt_Region },
            {   76, MenuType::mt_SelectStateDiagram },
            {   77, MenuType::mt_Send_Signal },
            {   78, MenuType::mt_ShallowHistory },
            {   79, MenuType::mt_State },
            {   80, MenuType::mt_StateFork },
            {   81, MenuType::mt_StateJoin },
            {   82, MenuType::mt_StateTransition },
            {   83, MenuType::mt_Subsystem },
            {   84, MenuType::mt_Template },
            {   85, MenuType::mt_Union },
            {   86, MenuType::mt_UniqueConstraint },
            {   87, MenuType::mt_UseCase },
            {   88, MenuType::mt_New_Activity },
            {   89, MenuType::mt_New_Attribute },
            {   90, MenuType::mt_New_EntityAttribute },
            {   91, MenuType::mt_New_EnumLiteral },
            {   92, MenuType::mt_New_InstanceAttribute },
            {   93, MenuType::mt_New_Operation },
            {   94, MenuType::mt_New_Parameter },
            {   95, MenuType::mt_New_Template },
            {   96, MenuType::mt_RemoveStateDiagram },
            {   97, MenuType::mt_ReturnToClass },
            {   98, MenuType::mt_ReturnToCombinedState },
            {   99, MenuType::mt_Hide_Attribute_Signature_Selection },
            {  100, MenuType::mt_Hide_Attributes_Selection },
            {  101, MenuType::mt_Hide_Destruction_Box },
            {  102, MenuType::mt_Hide_NonPublic_Selection },
            {  103, MenuType::mt_Hide_Operation_Signature_Selection },
            {  104, MenuType::mt_Hide_Operations_Selection },
            {  105, MenuType::mt_Hide_Packages_Selection },
            {  106, MenuType::mt_Hide_Stereotypes_Selection },
            {  107, MenuType::mt_Hide_Visibility_Selection },
            {  108, MenuType::mt_Show_Attribute_Signature },
            {  109, MenuType::mt_Show_Attribute_Signature_Selection },
            {  110, MenuType::mt_Show_Attributes_Selection },
            {  111, MenuType::mt_Show_Attributes },
            {  112, MenuType::mt_Show_Destruction_Box },
            {  113, MenuType::mt_Show_Documentation },
            {  114, MenuType::mt_Show_NonPublic_Selection },
            {  115, MenuType::mt_Show_Operation_Signature },
            {  116, MenuType::mt_Show_Operation_Signature_Selection },
            {  117, MenuType::mt_Show_Operations_Selection },
            {  118, MenuType::mt_Show_Operations },
            {  119, MenuType::mt_Show_Packages },
            {  120, MenuType::mt_Show_Packages_Selection },
            {  121, MenuType::mt_Show_Public_Only },
            {  122, MenuType::mt_Show_Stereotypes },
            {  123, MenuType::mt_Show_Stereotypes_Selection },
            {  124, MenuType::mt_Show_Visibility_Selection },
            {  125, MenuType::mt_Visibility },
            {  126, MenuType::mt_DrawAsCircle },
            {  127, MenuType::mt_ChangeToClass },
            {  128, MenuType::mt_ChangeToInterface },
            {  129, MenuType::mt_ChangeToPackage },
            {  130, MenuType::mt_Open_File },
            {  131, MenuType::mt_Rename_Object },
            {  132, MenuType::mt_Select_Operation },
            {  133, MenuType::mt_Properties },
            {  134, MenuType::mt_Rename },
            {  135, MenuType::mt_NameAsTooltip },
            {  136, MenuType::mt_Show },
            {  137, MenuType::mt_Delete },
            {  138, MenuType::mt_Export_Image },
            {  139, MenuType::mt_Import_Class },
            {  140, MenuType::mt_Import_Project },
            {  141, MenuType::mt_Cut },
            {  142, MenuType::mt_Copy },
            {  143, MenuType::mt_Paste },
            {  144, MenuType::mt_Clear },
            {  145, MenuType::mt_Redo },
            {  146, MenuType::mt_Undo },
            {  147, MenuType::mt_Reset_Label_Positions },
            {  148, MenuType::mt_Line_Color },
            {  149, MenuType::mt_Line_Color_Selection },
            {  150, MenuType::mt_Fill_Color },
            {  151, MenuType::mt_Fill_Color_Selection },
            {  152, MenuType::mt_Use_Fill_Color },
            {  153, MenuType::mt_Set_Use_Fill_Color_Selection },
            {  154, MenuType::mt_Unset_Use_Fill_Color_Selection },
            {  155, MenuType::mt_Rename_MultiA },
            {  156, MenuType::mt_Rename_MultiB },
            {  157, MenuType::mt_Rename_Name },
            {  158, MenuType::mt_Rename_RoleAName },
            {  159, MenuType::mt_Rename_RoleBName },
            {  160, MenuType::mt_Change_Font },
            {  161, MenuType::mt_Change_Font_Selection },
            {  162, MenuType::mt_SnapToGrid },
            {  163, MenuType::mt_SnapComponentSizeToGrid },
            {  164, MenuType::mt_ShowDocumentationIndicator },
            {  165, MenuType::mt_ShowSnapGrid },
            {  166, MenuType::mt_AutoResize },
            {  167, MenuType::mt_Resize },
            {  168, MenuType::mt_Up },
            {  169, MenuType::mt_Down },
            {  170, MenuType::mt_FlipHorizontal },
            {  171, MenuType::mt_FlipVertical },
            {  172, MenuType::mt_Add_Point },
            {  173, MenuType::mt_Delete_Point },
            {  174, MenuType::mt_Auto_Layout_Spline },
            {  175, MenuType::mt_Expand_All },
            {  176, MenuType::mt_Collapse_All },
            {  177, MenuType::mt_Refactoring },
            {  178, MenuType::mt_ViewCode },
            {  179, MenuType::mt_Clone },
            {  180, MenuType::mt_Externalize_Folder },
            {  181, MenuType::mt_Internalize_Folder },
            {  182, MenuType::mt_AddInteractionOperand },
            {  183, MenuType::mt_Apply_Layout },
            {  184, MenuType::mt_Apply_Layout1 },
            {  185, MenuType::mt_Apply_Layout2 },
            {  186, MenuType::mt_Apply_Layout3 },
            {  187, MenuType::mt_Apply_Layout4 },
            {  188, MenuType::mt_Apply_Layout5 },
            {  189, MenuType::mt_Apply_Layout6 },
            {  190, MenuType::mt_Apply_Layout7 },
            {  191, MenuType::mt_Apply_Layout8 },
            {  192, MenuType::mt_Apply_Layout9 },
            {  193, MenuType::mt_LayoutDirect },
            {  194, MenuType::mt_LayoutSpline },
            {  195, MenuType::mt_LayoutOrthogonal },
            {  196, MenuType::mt_LayoutPolyline },
            {  197, MenuType::mt_Align_Right },
            {  198, MenuType::mt_Align_Left },
            {  199, MenuType::mt_Align_Top },
            {  200, MenuType::mt_Align_Bottom },
            {  201, MenuType::mt_Align_VerticalMiddle },
            {  202, MenuType::mt_Align_HorizontalMiddle },
            {  203, MenuType::mt_Align_VerticalDistribute },
            {  204, MenuType::mt_Align_HorizontalDistribute },
            {  205, MenuType::mt_Import_from_File },
            {  206, MenuType::mt_Remove },
            {  207, MenuType::mt_Undefined },
        }),
        // enum 'DataType'
        QtMocHelpers::EnumData<enum DataType>(208, 208, QMC::EnumFlags{}).add({
            {  209, DataType::dt_MenuPointer },
            {  210, DataType::dt_ApplyLayout },
        }),
    };
    return QtMocHelpers::metaObjectData<ListPopupMenu, qt_meta_tag_ZN13ListPopupMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ListPopupMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QMenu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ListPopupMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ListPopupMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ListPopupMenuE_t>.metaTypes,
    nullptr
} };

void ListPopupMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ListPopupMenu *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ListPopupMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ListPopupMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ListPopupMenuE_t>.strings))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int ListPopupMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
