/****************************************************************************
** Meta object code from reading C++ file 'umldoc.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.90/umbrello/umldoc.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'umldoc.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6UMLDocE_t {};
} // unnamed namespace

template <> constexpr inline auto UMLDoc::qt_create_metaobjectdata<qt_meta_tag_ZN6UMLDocE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UMLDoc",
        "sigDiagramCreated",
        "",
        "Uml::ID::Type",
        "id",
        "sigDiagramRemoved",
        "sigDiagramRenamed",
        "t",
        "sigDiagramChanged",
        "Uml::DiagramType::Enum",
        "sigObjectCreated",
        "UMLObject*",
        "sigObjectRemoved",
        "sigResetStatusbarProgress",
        "sigSetStatusbarProgressSteps",
        "totalSteps",
        "sigSetStatusbarProgress",
        "stepPosition",
        "sigWriteToStatusBar",
        "text",
        "sigCurrentViewChanged",
        "slotRemoveUMLObject",
        "o",
        "slotAutoSave",
        "slotDiagramPopupMenu",
        "QWidget*",
        "umlview",
        "QPoint",
        "point"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigDiagramCreated'
        QtMocHelpers::SignalData<void(Uml::ID::Type)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigDiagramRemoved'
        QtMocHelpers::SignalData<void(Uml::ID::Type)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigDiagramRenamed'
        QtMocHelpers::SignalData<void(Uml::ID::Type)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Signal 'sigDiagramChanged'
        QtMocHelpers::SignalData<void(Uml::DiagramType::Enum)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'sigObjectCreated'
        QtMocHelpers::SignalData<void(UMLObject *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'sigObjectRemoved'
        QtMocHelpers::SignalData<void(UMLObject *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'sigResetStatusbarProgress'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigSetStatusbarProgressSteps'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Signal 'sigSetStatusbarProgress'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Signal 'sigWriteToStatusBar'
        QtMocHelpers::SignalData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'sigCurrentViewChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveUMLObject'
        QtMocHelpers::SlotData<void(UMLObject *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 22 },
        }}),
        // Slot 'slotAutoSave'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDiagramPopupMenu'
        QtMocHelpers::SlotData<void(QWidget *, const QPoint &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UMLDoc, qt_meta_tag_ZN6UMLDocE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UMLDoc::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6UMLDocE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6UMLDocE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6UMLDocE_t>.metaTypes,
    nullptr
} };

void UMLDoc::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UMLDoc *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigDiagramCreated((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 1: _t->sigDiagramRemoved((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 2: _t->sigDiagramRenamed((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 3: _t->sigDiagramChanged((*reinterpret_cast<std::add_pointer_t<Uml::DiagramType::Enum>>(_a[1]))); break;
        case 4: _t->sigObjectCreated((*reinterpret_cast<std::add_pointer_t<UMLObject*>>(_a[1]))); break;
        case 5: _t->sigObjectRemoved((*reinterpret_cast<std::add_pointer_t<UMLObject*>>(_a[1]))); break;
        case 6: _t->sigResetStatusbarProgress(); break;
        case 7: _t->sigSetStatusbarProgressSteps((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->sigSetStatusbarProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->sigWriteToStatusBar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->sigCurrentViewChanged(); break;
        case 11: _t->slotRemoveUMLObject((*reinterpret_cast<std::add_pointer_t<UMLObject*>>(_a[1]))); break;
        case 12: _t->slotAutoSave(); break;
        case 13: _t->slotDiagramPopupMenu((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLObject* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLObject* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLObject* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)(Uml::ID::Type )>(_a, &UMLDoc::sigDiagramCreated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)(Uml::ID::Type )>(_a, &UMLDoc::sigDiagramRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)(Uml::ID::Type )>(_a, &UMLDoc::sigDiagramRenamed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)(Uml::DiagramType::Enum )>(_a, &UMLDoc::sigDiagramChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)(UMLObject * )>(_a, &UMLDoc::sigObjectCreated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)(UMLObject * )>(_a, &UMLDoc::sigObjectRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)()>(_a, &UMLDoc::sigResetStatusbarProgress, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)(int )>(_a, &UMLDoc::sigSetStatusbarProgressSteps, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)(int )>(_a, &UMLDoc::sigSetStatusbarProgress, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)(const QString & )>(_a, &UMLDoc::sigWriteToStatusBar, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLDoc::*)()>(_a, &UMLDoc::sigCurrentViewChanged, 10))
            return;
    }
}

const QMetaObject *UMLDoc::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UMLDoc::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6UMLDocE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UMLDoc::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void UMLDoc::sigDiagramCreated(Uml::ID::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UMLDoc::sigDiagramRemoved(Uml::ID::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UMLDoc::sigDiagramRenamed(Uml::ID::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UMLDoc::sigDiagramChanged(Uml::DiagramType::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UMLDoc::sigObjectCreated(UMLObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void UMLDoc::sigObjectRemoved(UMLObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void UMLDoc::sigResetStatusbarProgress()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void UMLDoc::sigSetStatusbarProgressSteps(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void UMLDoc::sigSetStatusbarProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void UMLDoc::sigWriteToStatusBar(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void UMLDoc::sigCurrentViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
