/********************************************************************************
** Form generated from reading UI file 'codeimportoptionspage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CODEIMPORTOPTIONSPAGE_H
#define UI_CODEIMPORTOPTIONSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CodeImportOptionsPage
{
public:
    QGridLayout *gridLayout_2;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox_2;
    QLabel *label;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QCheckBox *createArtifactCheckBox;
    QCheckBox *resolveDependenciesCheckBox;
    QCheckBox *supportCPP11CheckBox;

    void setupUi(QWidget *CodeImportOptionsPage)
    {
        if (CodeImportOptionsPage->objectName().isEmpty())
            CodeImportOptionsPage->setObjectName("CodeImportOptionsPage");
        CodeImportOptionsPage->resize(561, 244);
        gridLayout_2 = new QGridLayout(CodeImportOptionsPage);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        groupBox_2 = new QGroupBox(CodeImportOptionsPage);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy);
        groupBox_2->setMinimumSize(QSize(0, 100));
        label = new QLabel(groupBox_2);
        label->setObjectName("label");
        label->setGeometry(QRect(10, 30, 513, 41));
        label->setWordWrap(true);

        verticalLayout_3->addWidget(groupBox_2);


        gridLayout_2->addLayout(verticalLayout_3, 0, 0, 1, 1);

        groupBox = new QGroupBox(CodeImportOptionsPage);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        createArtifactCheckBox = new QCheckBox(groupBox);
        createArtifactCheckBox->setObjectName("createArtifactCheckBox");

        verticalLayout->addWidget(createArtifactCheckBox);

        resolveDependenciesCheckBox = new QCheckBox(groupBox);
        resolveDependenciesCheckBox->setObjectName("resolveDependenciesCheckBox");

        verticalLayout->addWidget(resolveDependenciesCheckBox);

        supportCPP11CheckBox = new QCheckBox(groupBox);
        supportCPP11CheckBox->setObjectName("supportCPP11CheckBox");

        verticalLayout->addWidget(supportCPP11CheckBox);


        verticalLayout_2->addLayout(verticalLayout);


        gridLayout->addLayout(verticalLayout_2, 0, 0, 1, 1);


        gridLayout_2->addWidget(groupBox, 1, 0, 1, 1);


        retranslateUi(CodeImportOptionsPage);

        QMetaObject::connectSlotsByName(CodeImportOptionsPage);
    } // setupUi

    void retranslateUi(QWidget *CodeImportOptionsPage)
    {
        groupBox_2->setTitle(tr2i18n("Include search paths", nullptr));
        label->setText(tr2i18n("Additional include search paths could be added by specifying environment variable UMBRELLO_INCPATH.", nullptr));
        groupBox->setTitle(tr2i18n("C++ Import", nullptr));
        createArtifactCheckBox->setText(tr2i18n("For each imported file create an artifact in the component view", nullptr));
        resolveDependenciesCheckBox->setText(tr2i18n("Resolve dependencies (reduces import speed)", nullptr));
        supportCPP11CheckBox->setText(tr2i18n("Enable C++11 standard (experimental)", nullptr));
        (void)CodeImportOptionsPage;
    } // retranslateUi

};

namespace Ui {
    class CodeImportOptionsPage: public Ui_CodeImportOptionsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CODEIMPORTOPTIONSPAGE_H

