/****************************************************************************
** Meta object code from reading C++ file 'refactoringassistant.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.90/umbrello/refactoring/refactoringassistant.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'refactoringassistant.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20RefactoringAssistantE_t {};
} // unnamed namespace

template <> constexpr inline auto RefactoringAssistant::qt_create_metaobjectdata<qt_meta_tag_ZN20RefactoringAssistantE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RefactoringAssistant",
        "addBaseClassifier",
        "",
        "addDerivedClassifier",
        "addInterfaceImplementation",
        "createOperation",
        "createAttribute",
        "editProperties",
        "deleteItem",
        "objectModified",
        "operationAdded",
        "UMLClassifierListItem*",
        "listItem",
        "operationRemoved",
        "attributeAdded",
        "attributeRemoved",
        "itemExecuted",
        "QTreeWidgetItem*",
        "item",
        "column",
        "showContextMenu",
        "QPoint"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addBaseClassifier'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addDerivedClassifier'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addInterfaceImplementation'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createOperation'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createAttribute'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editProperties'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteItem'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'objectModified'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'operationAdded'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'operationRemoved'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'attributeAdded'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'attributeRemoved'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'itemExecuted'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'showContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RefactoringAssistant, qt_meta_tag_ZN20RefactoringAssistantE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RefactoringAssistant::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20RefactoringAssistantE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20RefactoringAssistantE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20RefactoringAssistantE_t>.metaTypes,
    nullptr
} };

void RefactoringAssistant::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RefactoringAssistant *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addBaseClassifier(); break;
        case 1: _t->addDerivedClassifier(); break;
        case 2: _t->addInterfaceImplementation(); break;
        case 3: _t->createOperation(); break;
        case 4: _t->createAttribute(); break;
        case 5: _t->editProperties(); break;
        case 6: _t->deleteItem(); break;
        case 7: _t->objectModified(); break;
        case 8: _t->operationAdded((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 9: _t->operationRemoved((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 10: _t->attributeAdded((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 11: _t->attributeRemoved((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 12: _t->itemExecuted((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->showContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *RefactoringAssistant::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RefactoringAssistant::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20RefactoringAssistantE_t>.strings))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int RefactoringAssistant::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
