/****************************************************************************
** Meta object code from reading C++ file 'activitywidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.90/umbrello/umlwidgets/activitywidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'activitywidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ActivityWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto ActivityWidget::qt_create_metaobjectdata<qt_meta_tag_ZN14ActivityWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActivityWidget",
        "sigActMoved",
        "",
        "diffX",
        "diffY",
        "slotMenuSelection",
        "QAction*",
        "action",
        "ActivityType",
        "Initial",
        "Normal",
        "End",
        "Final",
        "Branch",
        "Invok",
        "Param"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigActMoved'
        QtMocHelpers::SignalData<void(qreal, qreal)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 3 }, { QMetaType::QReal, 4 },
        }}),
        // Slot 'slotMenuSelection'
        QtMocHelpers::SlotData<void(QAction *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ActivityType'
        QtMocHelpers::EnumData<enum ActivityType>(8, 8, QMC::EnumFlags{}).add({
            {    9, ActivityType::Initial },
            {   10, ActivityType::Normal },
            {   11, ActivityType::End },
            {   12, ActivityType::Final },
            {   13, ActivityType::Branch },
            {   14, ActivityType::Invok },
            {   15, ActivityType::Param },
        }),
    };
    return QtMocHelpers::metaObjectData<ActivityWidget, qt_meta_tag_ZN14ActivityWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ActivityWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<UMLWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ActivityWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ActivityWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ActivityWidgetE_t>.metaTypes,
    nullptr
} };

void ActivityWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActivityWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigActMoved((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 1: _t->slotMenuSelection((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActivityWidget::*)(qreal , qreal )>(_a, &ActivityWidget::sigActMoved, 0))
            return;
    }
}

const QMetaObject *ActivityWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ActivityWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ActivityWidgetE_t>.strings))
        return static_cast<void*>(this);
    return UMLWidget::qt_metacast(_clname);
}

int ActivityWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UMLWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ActivityWidget::sigActMoved(qreal _t1, qreal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
