/********************************************************************************
** Form generated from reading UI file 'finddialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FINDDIALOG_H
#define UI_FINDDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FindDialog
{
public:
    QHBoxLayout *horizontalLayout_3;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *ui_treeView;
    QRadioButton *ui_CurrentDiagram;
    QRadioButton *ui_Diagrams;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout_5;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *ui_categoryAll;
    QRadioButton *ui_categoryClass;
    QRadioButton *ui_categoryPackage;
    QRadioButton *ui_categoryInterface;
    QRadioButton *ui_categoryOperation;
    QRadioButton *ui_categoryAttribute;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QLineEdit *ui_searchTerm;
    QButtonGroup *ui_buttonGroup;

    void setupUi(QWidget *FindDialog)
    {
        if (FindDialog->objectName().isEmpty())
            FindDialog->setObjectName("FindDialog");
        FindDialog->resize(520, 268);
        FindDialog->setMinimumSize(QSize(441, 268));
        horizontalLayout_3 = new QHBoxLayout(FindDialog);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        groupBox_2 = new QGroupBox(FindDialog);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        ui_treeView = new QRadioButton(groupBox_2);
        ui_buttonGroup = new QButtonGroup(FindDialog);
        ui_buttonGroup->setObjectName("ui_buttonGroup");
        ui_buttonGroup->addButton(ui_treeView);
        ui_treeView->setObjectName("ui_treeView");

        horizontalLayout_2->addWidget(ui_treeView);

        ui_CurrentDiagram = new QRadioButton(groupBox_2);
        ui_buttonGroup->addButton(ui_CurrentDiagram);
        ui_CurrentDiagram->setObjectName("ui_CurrentDiagram");

        horizontalLayout_2->addWidget(ui_CurrentDiagram);

        ui_Diagrams = new QRadioButton(groupBox_2);
        ui_buttonGroup->addButton(ui_Diagrams);
        ui_Diagrams->setObjectName("ui_Diagrams");

        horizontalLayout_2->addWidget(ui_Diagrams);


        verticalLayout_2->addLayout(horizontalLayout_2);

        ui_Diagrams->raise();
        ui_CurrentDiagram->raise();
        ui_treeView->raise();
        ui_Diagrams->raise();
        ui_CurrentDiagram->raise();
        ui_treeView->raise();

        verticalLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(FindDialog);
        groupBox->setObjectName("groupBox");
        horizontalLayout_5 = new QHBoxLayout(groupBox);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        ui_categoryAll = new QRadioButton(groupBox);
        ui_categoryAll->setObjectName("ui_categoryAll");

        horizontalLayout_4->addWidget(ui_categoryAll);

        ui_categoryClass = new QRadioButton(groupBox);
        ui_categoryClass->setObjectName("ui_categoryClass");

        horizontalLayout_4->addWidget(ui_categoryClass);

        ui_categoryPackage = new QRadioButton(groupBox);
        ui_categoryPackage->setObjectName("ui_categoryPackage");

        horizontalLayout_4->addWidget(ui_categoryPackage);

        ui_categoryInterface = new QRadioButton(groupBox);
        ui_categoryInterface->setObjectName("ui_categoryInterface");

        horizontalLayout_4->addWidget(ui_categoryInterface);

        ui_categoryOperation = new QRadioButton(groupBox);
        ui_categoryOperation->setObjectName("ui_categoryOperation");

        horizontalLayout_4->addWidget(ui_categoryOperation);

        ui_categoryAttribute = new QRadioButton(groupBox);
        ui_categoryAttribute->setObjectName("ui_categoryAttribute");

        horizontalLayout_4->addWidget(ui_categoryAttribute);


        horizontalLayout_5->addLayout(horizontalLayout_4);


        verticalLayout->addWidget(groupBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_2 = new QLabel(FindDialog);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        ui_searchTerm = new QLineEdit(FindDialog);
        ui_searchTerm->setObjectName("ui_searchTerm");

        horizontalLayout->addWidget(ui_searchTerm);


        verticalLayout->addLayout(horizontalLayout);


        horizontalLayout_3->addLayout(verticalLayout);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(ui_searchTerm);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(ui_searchTerm, ui_treeView);
        QWidget::setTabOrder(ui_treeView, ui_CurrentDiagram);
        QWidget::setTabOrder(ui_CurrentDiagram, ui_Diagrams);

        retranslateUi(FindDialog);

        QMetaObject::connectSlotsByName(FindDialog);
    } // setupUi

    void retranslateUi(QWidget *FindDialog)
    {
        groupBox_2->setTitle(tr2i18n("Filter", nullptr));
        ui_treeView->setText(tr2i18n("Tree View", nullptr));
        ui_CurrentDiagram->setText(tr2i18n("&Current diagram", nullptr));
        ui_Diagrams->setText(tr2i18n("&All diagrams", nullptr));
        groupBox->setTitle(tr2i18n("Category", nullptr));
        ui_categoryAll->setText(tr2i18n("All", nullptr));
        ui_categoryClass->setText(tr2i18n("Class", nullptr));
        ui_categoryPackage->setText(tr2i18n("Package", nullptr));
        ui_categoryInterface->setText(tr2i18n("Interface", nullptr));
        ui_categoryOperation->setText(tr2i18n("Operation", nullptr));
        ui_categoryAttribute->setText(tr2i18n("Attribute", nullptr));
        label_2->setText(tr2i18n("Search Term:", nullptr));
        (void)FindDialog;
    } // retranslateUi

};

namespace Ui {
    class FindDialog: public Ui_FindDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FINDDIALOG_H

