/********************************************************************************
** Form generated from reading UI file 'diagrampropertiespage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIAGRAMPROPERTIESPAGE_H
#define UI_DIAGRAMPROPERTIESPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DiagramPropertiesPage
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *ui_groupBoxDiagramProperties;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *ui_labelDiagramName;
    QLineEdit *ui_diagramName;
    QHBoxLayout *hboxLayout1;
    QHBoxLayout *hboxLayout2;
    QLabel *ui_labelZoom;
    QSpinBox *ui_zoom;
    QLabel *ui_labelZoomUnit;
    QSpacerItem *horizontalSpacer_2;
    QLabel *ui_labelWidth;
    QDoubleSpinBox *ui_width;
    QSpacerItem *horizontalSpacer_3;
    QLabel *ui_labelHeight;
    QDoubleSpinBox *ui_height;
    QFrame *ui_line;
    QHBoxLayout *hboxLayout3;
    QCheckBox *ui_checkBoxShowGrid;
    QCheckBox *ui_snapToGrid;
    QCheckBox *ui_snapComponentSizeToGrid;
    QHBoxLayout *hboxLayout4;
    QLabel *ui_labelGridSpacing;
    QSpacerItem *horizontalSpacer;
    QLabel *ui_labelX;
    QSpinBox *ui_gridSpaceX;
    QSpacerItem *spacerItem;
    QLabel *ui_labelY;
    QSpinBox *ui_gridSpaceY;
    QFrame *line;
    QCheckBox *ui_autoIncrementSequence;
    QGroupBox *ui_groupBoxDocumentation;
    QGridLayout *gridLayout;
    QTextEdit *ui_documentation;

    void setupUi(QWidget *DiagramPropertiesPage)
    {
        if (DiagramPropertiesPage->objectName().isEmpty())
            DiagramPropertiesPage->setObjectName("DiagramPropertiesPage");
        DiagramPropertiesPage->resize(449, 515);
        vboxLayout = new QVBoxLayout(DiagramPropertiesPage);
        vboxLayout->setObjectName("vboxLayout");
        ui_groupBoxDiagramProperties = new QGroupBox(DiagramPropertiesPage);
        ui_groupBoxDiagramProperties->setObjectName("ui_groupBoxDiagramProperties");
        vboxLayout1 = new QVBoxLayout(ui_groupBoxDiagramProperties);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MACOS
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        ui_labelDiagramName = new QLabel(ui_groupBoxDiagramProperties);
        ui_labelDiagramName->setObjectName("ui_labelDiagramName");
        ui_labelDiagramName->setWordWrap(false);

        hboxLayout->addWidget(ui_labelDiagramName);

        ui_diagramName = new QLineEdit(ui_groupBoxDiagramProperties);
        ui_diagramName->setObjectName("ui_diagramName");

        hboxLayout->addWidget(ui_diagramName);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout2 = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout2->setObjectName("hboxLayout2");
        ui_labelZoom = new QLabel(ui_groupBoxDiagramProperties);
        ui_labelZoom->setObjectName("ui_labelZoom");
        ui_labelZoom->setWordWrap(false);

        hboxLayout2->addWidget(ui_labelZoom);

        ui_zoom = new QSpinBox(ui_groupBoxDiagramProperties);
        ui_zoom->setObjectName("ui_zoom");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ui_zoom->sizePolicy().hasHeightForWidth());
        ui_zoom->setSizePolicy(sizePolicy);
        ui_zoom->setMinimum(10);
        ui_zoom->setMaximum(500);

        hboxLayout2->addWidget(ui_zoom);

        ui_labelZoomUnit = new QLabel(ui_groupBoxDiagramProperties);
        ui_labelZoomUnit->setObjectName("ui_labelZoomUnit");
        ui_labelZoomUnit->setWordWrap(false);

        hboxLayout2->addWidget(ui_labelZoomUnit);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(horizontalSpacer_2);

        ui_labelWidth = new QLabel(ui_groupBoxDiagramProperties);
        ui_labelWidth->setObjectName("ui_labelWidth");

        hboxLayout2->addWidget(ui_labelWidth);

        ui_width = new QDoubleSpinBox(ui_groupBoxDiagramProperties);
        ui_width->setObjectName("ui_width");
        ui_width->setDecimals(1);
        ui_width->setMinimum(640.000000000000000);
        ui_width->setMaximum(11000.000000000000000);
        ui_width->setSingleStep(20.000000000000000);
        ui_width->setValue(1100.000000000000000);

        hboxLayout2->addWidget(ui_width);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(horizontalSpacer_3);

        ui_labelHeight = new QLabel(ui_groupBoxDiagramProperties);
        ui_labelHeight->setObjectName("ui_labelHeight");

        hboxLayout2->addWidget(ui_labelHeight);

        ui_height = new QDoubleSpinBox(ui_groupBoxDiagramProperties);
        ui_height->setObjectName("ui_height");
        ui_height->setDecimals(1);
        ui_height->setMinimum(400.000000000000000);
        ui_height->setMaximum(8000.000000000000000);
        ui_height->setSingleStep(20.000000000000000);
        ui_height->setValue(800.000000000000000);

        hboxLayout2->addWidget(ui_height);


        hboxLayout1->addLayout(hboxLayout2);


        vboxLayout1->addLayout(hboxLayout1);

        ui_line = new QFrame(ui_groupBoxDiagramProperties);
        ui_line->setObjectName("ui_line");
        ui_line->setFrameShape(QFrame::HLine);
        ui_line->setFrameShadow(QFrame::Sunken);

        vboxLayout1->addWidget(ui_line);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName("hboxLayout3");
        ui_checkBoxShowGrid = new QCheckBox(ui_groupBoxDiagramProperties);
        ui_checkBoxShowGrid->setObjectName("ui_checkBoxShowGrid");

        hboxLayout3->addWidget(ui_checkBoxShowGrid);

        ui_snapToGrid = new QCheckBox(ui_groupBoxDiagramProperties);
        ui_snapToGrid->setObjectName("ui_snapToGrid");

        hboxLayout3->addWidget(ui_snapToGrid);

        ui_snapComponentSizeToGrid = new QCheckBox(ui_groupBoxDiagramProperties);
        ui_snapComponentSizeToGrid->setObjectName("ui_snapComponentSizeToGrid");

        hboxLayout3->addWidget(ui_snapComponentSizeToGrid);


        vboxLayout1->addLayout(hboxLayout3);

        hboxLayout4 = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        hboxLayout4->setSpacing(6);
#endif
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        hboxLayout4->setObjectName("hboxLayout4");
        ui_labelGridSpacing = new QLabel(ui_groupBoxDiagramProperties);
        ui_labelGridSpacing->setObjectName("ui_labelGridSpacing");
        ui_labelGridSpacing->setWordWrap(false);

        hboxLayout4->addWidget(ui_labelGridSpacing);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(horizontalSpacer);

        ui_labelX = new QLabel(ui_groupBoxDiagramProperties);
        ui_labelX->setObjectName("ui_labelX");
        ui_labelX->setWordWrap(false);

        hboxLayout4->addWidget(ui_labelX);

        ui_gridSpaceX = new QSpinBox(ui_groupBoxDiagramProperties);
        ui_gridSpaceX->setObjectName("ui_gridSpaceX");
        ui_gridSpaceX->setMinimum(5);
        ui_gridSpaceX->setMaximum(100);

        hboxLayout4->addWidget(ui_gridSpaceX);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem);

        ui_labelY = new QLabel(ui_groupBoxDiagramProperties);
        ui_labelY->setObjectName("ui_labelY");
        ui_labelY->setWordWrap(false);

        hboxLayout4->addWidget(ui_labelY);

        ui_gridSpaceY = new QSpinBox(ui_groupBoxDiagramProperties);
        ui_gridSpaceY->setObjectName("ui_gridSpaceY");
        ui_gridSpaceY->setMinimum(5);
        ui_gridSpaceY->setMaximum(100);

        hboxLayout4->addWidget(ui_gridSpaceY);


        vboxLayout1->addLayout(hboxLayout4);

        line = new QFrame(ui_groupBoxDiagramProperties);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        vboxLayout1->addWidget(line);

        ui_autoIncrementSequence = new QCheckBox(ui_groupBoxDiagramProperties);
        ui_autoIncrementSequence->setObjectName("ui_autoIncrementSequence");

        vboxLayout1->addWidget(ui_autoIncrementSequence);


        vboxLayout->addWidget(ui_groupBoxDiagramProperties);

        ui_groupBoxDocumentation = new QGroupBox(DiagramPropertiesPage);
        ui_groupBoxDocumentation->setObjectName("ui_groupBoxDocumentation");
        gridLayout = new QGridLayout(ui_groupBoxDocumentation);
#ifndef UI_Q_OS_MACOS
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        ui_documentation = new QTextEdit(ui_groupBoxDocumentation);
        ui_documentation->setObjectName("ui_documentation");

        gridLayout->addWidget(ui_documentation, 0, 0, 1, 1);


        vboxLayout->addWidget(ui_groupBoxDocumentation);


        retranslateUi(DiagramPropertiesPage);

        QMetaObject::connectSlotsByName(DiagramPropertiesPage);
    } // setupUi

    void retranslateUi(QWidget *DiagramPropertiesPage)
    {
        ui_groupBoxDiagramProperties->setTitle(tr2i18n("Diagram Properties", nullptr));
        ui_labelDiagramName->setText(tr2i18n("Name:", nullptr));
        ui_labelZoom->setText(tr2i18n("Zoom:", nullptr));
        ui_labelZoomUnit->setText(tr2i18n("%", nullptr));
        ui_labelWidth->setText(tr2i18n("Width:", nullptr));
        ui_labelHeight->setText(tr2i18n("Height:", nullptr));
        ui_checkBoxShowGrid->setText(tr2i18n("Show &grid", nullptr));
        ui_snapToGrid->setText(tr2i18n("Snap &to grid", nullptr));
#if QT_CONFIG(whatsthis)
        ui_snapComponentSizeToGrid->setWhatsThis(tr2i18n("Snap the size of the components to be a multiple of the grid spacing.\n"
"If 'Snap to Grid' is enabled a component will always be aligned with the grid on all 4 sides.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ui_snapComponentSizeToGrid->setText(tr2i18n("Snap component size", nullptr));
        ui_labelGridSpacing->setText(tr2i18n("Grid spacing:  ", nullptr));
        ui_labelX->setText(tr2i18n("X", nullptr));
        ui_labelY->setText(tr2i18n("Y", nullptr));
        ui_autoIncrementSequence->setText(tr2i18n("Autoincrement Sequence ", nullptr));
        ui_groupBoxDocumentation->setTitle(tr2i18n("Documentation", nullptr));
        (void)DiagramPropertiesPage;
    } // retranslateUi

};

namespace Ui {
    class DiagramPropertiesPage: public Ui_DiagramPropertiesPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DIAGRAMPROPERTIESPAGE_H

