/********************************************************************************
** Form generated from reading UI file 'umlrolepropertiesbase.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UMLROLEPROPERTIESBASE_H
#define UI_UMLROLEPROPERTIESBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_UMLRolePropertiesBase
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *ui_propsGroupBox;
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    QLabel *ui_labelRoleName;
    QLineEdit *ui_pRoleLE;
    QLabel *ui_labelMultiplicity;
    QLineEdit *ui_pMultiLE;
    QGroupBox *ui_visibilityButtonGroup;
    QHBoxLayout *hboxLayout;
    QRadioButton *ui_pPublicRB;
    QRadioButton *ui_pPrivateRB;
    QRadioButton *ui_pProtectedRB;
    QRadioButton *ui_pImplementationRB;
    QGroupBox *ui_changeabilityButtonGroup;
    QHBoxLayout *hboxLayout1;
    QRadioButton *ui_pChangeableRB;
    QRadioButton *ui_pFrozenRB;
    QRadioButton *ui_pAddOnlyRB;
    QGroupBox *ui_groupBoxDocumentation;
    QVBoxLayout *vboxLayout1;
    QTextEdit *ui_pDocTE;

    void setupUi(QWidget *UMLRolePropertiesBase)
    {
        if (UMLRolePropertiesBase->objectName().isEmpty())
            UMLRolePropertiesBase->setObjectName("UMLRolePropertiesBase");
        UMLRolePropertiesBase->resize(415, 540);
        vboxLayout = new QVBoxLayout(UMLRolePropertiesBase);
        vboxLayout->setObjectName("vboxLayout");
        ui_propsGroupBox = new QGroupBox(UMLRolePropertiesBase);
        ui_propsGroupBox->setObjectName("ui_propsGroupBox");
        gridLayout = new QGridLayout(ui_propsGroupBox);
        gridLayout->setObjectName("gridLayout");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        ui_labelRoleName = new QLabel(ui_propsGroupBox);
        ui_labelRoleName->setObjectName("ui_labelRoleName");
        ui_labelRoleName->setWordWrap(false);

        gridLayout1->addWidget(ui_labelRoleName, 0, 0, 1, 1);

        ui_pRoleLE = new QLineEdit(ui_propsGroupBox);
        ui_pRoleLE->setObjectName("ui_pRoleLE");

        gridLayout1->addWidget(ui_pRoleLE, 0, 1, 1, 1);

        ui_labelMultiplicity = new QLabel(ui_propsGroupBox);
        ui_labelMultiplicity->setObjectName("ui_labelMultiplicity");
        ui_labelMultiplicity->setWordWrap(false);

        gridLayout1->addWidget(ui_labelMultiplicity, 1, 0, 1, 1);

        ui_pMultiLE = new QLineEdit(ui_propsGroupBox);
        ui_pMultiLE->setObjectName("ui_pMultiLE");

        gridLayout1->addWidget(ui_pMultiLE, 1, 1, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);


        vboxLayout->addWidget(ui_propsGroupBox);

        ui_visibilityButtonGroup = new QGroupBox(UMLRolePropertiesBase);
        ui_visibilityButtonGroup->setObjectName("ui_visibilityButtonGroup");
        hboxLayout = new QHBoxLayout(ui_visibilityButtonGroup);
        hboxLayout->setObjectName("hboxLayout");
        ui_pPublicRB = new QRadioButton(ui_visibilityButtonGroup);
        ui_pPublicRB->setObjectName("ui_pPublicRB");
        ui_pPublicRB->setChecked(true);

        hboxLayout->addWidget(ui_pPublicRB);

        ui_pPrivateRB = new QRadioButton(ui_visibilityButtonGroup);
        ui_pPrivateRB->setObjectName("ui_pPrivateRB");

        hboxLayout->addWidget(ui_pPrivateRB);

        ui_pProtectedRB = new QRadioButton(ui_visibilityButtonGroup);
        ui_pProtectedRB->setObjectName("ui_pProtectedRB");

        hboxLayout->addWidget(ui_pProtectedRB);

        ui_pImplementationRB = new QRadioButton(ui_visibilityButtonGroup);
        ui_pImplementationRB->setObjectName("ui_pImplementationRB");

        hboxLayout->addWidget(ui_pImplementationRB);


        vboxLayout->addWidget(ui_visibilityButtonGroup);

        ui_changeabilityButtonGroup = new QGroupBox(UMLRolePropertiesBase);
        ui_changeabilityButtonGroup->setObjectName("ui_changeabilityButtonGroup");
        hboxLayout1 = new QHBoxLayout(ui_changeabilityButtonGroup);
        hboxLayout1->setObjectName("hboxLayout1");
        ui_pChangeableRB = new QRadioButton(ui_changeabilityButtonGroup);
        ui_pChangeableRB->setObjectName("ui_pChangeableRB");
        ui_pChangeableRB->setChecked(true);

        hboxLayout1->addWidget(ui_pChangeableRB);

        ui_pFrozenRB = new QRadioButton(ui_changeabilityButtonGroup);
        ui_pFrozenRB->setObjectName("ui_pFrozenRB");

        hboxLayout1->addWidget(ui_pFrozenRB);

        ui_pAddOnlyRB = new QRadioButton(ui_changeabilityButtonGroup);
        ui_pAddOnlyRB->setObjectName("ui_pAddOnlyRB");

        hboxLayout1->addWidget(ui_pAddOnlyRB);


        vboxLayout->addWidget(ui_changeabilityButtonGroup);

        ui_groupBoxDocumentation = new QGroupBox(UMLRolePropertiesBase);
        ui_groupBoxDocumentation->setObjectName("ui_groupBoxDocumentation");
        vboxLayout1 = new QVBoxLayout(ui_groupBoxDocumentation);
        vboxLayout1->setObjectName("vboxLayout1");
        ui_pDocTE = new QTextEdit(ui_groupBoxDocumentation);
        ui_pDocTE->setObjectName("ui_pDocTE");

        vboxLayout1->addWidget(ui_pDocTE);


        vboxLayout->addWidget(ui_groupBoxDocumentation);


        retranslateUi(UMLRolePropertiesBase);

        QMetaObject::connectSlotsByName(UMLRolePropertiesBase);
    } // setupUi

    void retranslateUi(QWidget *UMLRolePropertiesBase)
    {
        ui_propsGroupBox->setTitle(tr2i18n("Role Properties", nullptr));
        ui_labelRoleName->setText(tr2i18n("Rolename:", nullptr));
        ui_labelMultiplicity->setText(tr2i18n("Multiplicity:", nullptr));
        ui_visibilityButtonGroup->setTitle(tr2i18n("Role Visibility", nullptr));
        ui_pPublicRB->setText(tr2i18n("Public", nullptr));
        ui_pPrivateRB->setText(tr2i18n("Private", nullptr));
        ui_pProtectedRB->setText(tr2i18n("Protected", nullptr));
        ui_pImplementationRB->setText(tr2i18n("Implementation", nullptr));
        ui_changeabilityButtonGroup->setTitle(tr2i18n("Role Changeability", nullptr));
        ui_pChangeableRB->setText(tr2i18n("Changeable", nullptr));
        ui_pFrozenRB->setText(tr2i18n("Frozen", nullptr));
        ui_pAddOnlyRB->setText(tr2i18n("Add only", nullptr));
        ui_groupBoxDocumentation->setTitle(tr2i18n("Documentation", nullptr));
        (void)UMLRolePropertiesBase;
    } // retranslateUi

};

namespace Ui {
    class UMLRolePropertiesBase: public Ui_UMLRolePropertiesBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UMLROLEPROPERTIESBASE_H

