/********************************************************************************
** Form generated from reading UI file 'codegenoptionspage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CODEGENOPTIONSPAGE_H
#define UI_CODEGENOPTIONSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_CodeGenOptionsPage
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *ui_tabWidgetMain;
    QWidget *ui_tabGeneral;
    QVBoxLayout *vboxLayout1;
    QVBoxLayout *vboxLayout2;
    QGroupBox *ui_groupBoxLanguage;
    QVBoxLayout *vboxLayout3;
    KComboBox *ui_SelectLanguageBox;
    QGroupBox *ui_groupBoxFolders;
    QVBoxLayout *vboxLayout4;
    QLabel *ui_textLabelFolder;
    QHBoxLayout *hboxLayout;
    QLineEdit *ui_outputDir;
    QPushButton *ui_browseOutput;
    QCheckBox *ui_includeHeadings;
    QHBoxLayout *hboxLayout1;
    QLineEdit *ui_headingsDir;
    QPushButton *ui_browseHeadings;
    QGroupBox *ui_groupBoxOverwritePolicy;
    QVBoxLayout *vboxLayout5;
    QLabel *ui_textLabelOverwritePolicy;
    QVBoxLayout *vboxLayout6;
    QRadioButton *ui_radioButtonOverwrite;
    QRadioButton *ui_radioButtonAsk;
    QRadioButton *ui_radioButtonChangeName;
    QWidget *ui_tabFormatting;
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    QGroupBox *ui_groupBoxComment;
    QVBoxLayout *vboxLayout7;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QCheckBox *ui_forceDoc;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *ui_textLabelSectionComments;
    QComboBox *ui_writeSectionComments;
    QSpacerItem *verticalSpacer_3;
    QGroupBox *ui_groupBoxLines;
    QVBoxLayout *vboxLayout8;
    QHBoxLayout *hboxLayout2;
    QLabel *ui_textLabelType;
    KComboBox *ui_SelectIndentationTypeBox;
    QHBoxLayout *hboxLayout3;
    QLabel *ui_textLabelAmount;
    QSpinBox *ui_SelectIndentationNumber;
    QHBoxLayout *hboxLayout4;
    QLabel *ui_textLabelStyle;
    KComboBox *ui_SelectEndLineCharsBox;

    void setupUi(QWidget *CodeGenOptionsPage)
    {
        if (CodeGenOptionsPage->objectName().isEmpty())
            CodeGenOptionsPage->setObjectName("CodeGenOptionsPage");
        CodeGenOptionsPage->resize(500, 539);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CodeGenOptionsPage->sizePolicy().hasHeightForWidth());
        CodeGenOptionsPage->setSizePolicy(sizePolicy);
        vboxLayout = new QVBoxLayout(CodeGenOptionsPage);
        vboxLayout->setObjectName("vboxLayout");
        ui_tabWidgetMain = new QTabWidget(CodeGenOptionsPage);
        ui_tabWidgetMain->setObjectName("ui_tabWidgetMain");
        ui_tabWidgetMain->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ui_tabWidgetMain->sizePolicy().hasHeightForWidth());
        ui_tabWidgetMain->setSizePolicy(sizePolicy1);
        ui_tabGeneral = new QWidget();
        ui_tabGeneral->setObjectName("ui_tabGeneral");
        vboxLayout1 = new QVBoxLayout(ui_tabGeneral);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName("vboxLayout2");
        ui_groupBoxLanguage = new QGroupBox(ui_tabGeneral);
        ui_groupBoxLanguage->setObjectName("ui_groupBoxLanguage");
        sizePolicy1.setHeightForWidth(ui_groupBoxLanguage->sizePolicy().hasHeightForWidth());
        ui_groupBoxLanguage->setSizePolicy(sizePolicy1);
        vboxLayout3 = new QVBoxLayout(ui_groupBoxLanguage);
        vboxLayout3->setObjectName("vboxLayout3");
        ui_SelectLanguageBox = new KComboBox(ui_groupBoxLanguage);
        ui_SelectLanguageBox->setObjectName("ui_SelectLanguageBox");

        vboxLayout3->addWidget(ui_SelectLanguageBox);


        vboxLayout2->addWidget(ui_groupBoxLanguage);

        ui_groupBoxFolders = new QGroupBox(ui_tabGeneral);
        ui_groupBoxFolders->setObjectName("ui_groupBoxFolders");
        sizePolicy1.setHeightForWidth(ui_groupBoxFolders->sizePolicy().hasHeightForWidth());
        ui_groupBoxFolders->setSizePolicy(sizePolicy1);
        vboxLayout4 = new QVBoxLayout(ui_groupBoxFolders);
        vboxLayout4->setObjectName("vboxLayout4");
        ui_textLabelFolder = new QLabel(ui_groupBoxFolders);
        ui_textLabelFolder->setObjectName("ui_textLabelFolder");
        ui_textLabelFolder->setWordWrap(false);

        vboxLayout4->addWidget(ui_textLabelFolder);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        ui_outputDir = new QLineEdit(ui_groupBoxFolders);
        ui_outputDir->setObjectName("ui_outputDir");

        hboxLayout->addWidget(ui_outputDir);

        ui_browseOutput = new QPushButton(ui_groupBoxFolders);
        ui_browseOutput->setObjectName("ui_browseOutput");

        hboxLayout->addWidget(ui_browseOutput);


        vboxLayout4->addLayout(hboxLayout);

        ui_includeHeadings = new QCheckBox(ui_groupBoxFolders);
        ui_includeHeadings->setObjectName("ui_includeHeadings");
        ui_includeHeadings->setChecked(true);

        vboxLayout4->addWidget(ui_includeHeadings);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        ui_headingsDir = new QLineEdit(ui_groupBoxFolders);
        ui_headingsDir->setObjectName("ui_headingsDir");

        hboxLayout1->addWidget(ui_headingsDir);

        ui_browseHeadings = new QPushButton(ui_groupBoxFolders);
        ui_browseHeadings->setObjectName("ui_browseHeadings");

        hboxLayout1->addWidget(ui_browseHeadings);


        vboxLayout4->addLayout(hboxLayout1);


        vboxLayout2->addWidget(ui_groupBoxFolders);

        ui_groupBoxOverwritePolicy = new QGroupBox(ui_tabGeneral);
        ui_groupBoxOverwritePolicy->setObjectName("ui_groupBoxOverwritePolicy");
        vboxLayout5 = new QVBoxLayout(ui_groupBoxOverwritePolicy);
        vboxLayout5->setObjectName("vboxLayout5");
        ui_textLabelOverwritePolicy = new QLabel(ui_groupBoxOverwritePolicy);
        ui_textLabelOverwritePolicy->setObjectName("ui_textLabelOverwritePolicy");
        ui_textLabelOverwritePolicy->setWordWrap(false);

        vboxLayout5->addWidget(ui_textLabelOverwritePolicy);

        vboxLayout6 = new QVBoxLayout();
        vboxLayout6->setSpacing(0);
        vboxLayout6->setObjectName("vboxLayout6");
        vboxLayout6->setContentsMargins(0, 4, -1, 4);
        ui_radioButtonOverwrite = new QRadioButton(ui_groupBoxOverwritePolicy);
        ui_radioButtonOverwrite->setObjectName("ui_radioButtonOverwrite");

        vboxLayout6->addWidget(ui_radioButtonOverwrite);

        ui_radioButtonAsk = new QRadioButton(ui_groupBoxOverwritePolicy);
        ui_radioButtonAsk->setObjectName("ui_radioButtonAsk");
        ui_radioButtonAsk->setChecked(true);

        vboxLayout6->addWidget(ui_radioButtonAsk);

        ui_radioButtonChangeName = new QRadioButton(ui_groupBoxOverwritePolicy);
        ui_radioButtonChangeName->setObjectName("ui_radioButtonChangeName");

        vboxLayout6->addWidget(ui_radioButtonChangeName);


        vboxLayout5->addLayout(vboxLayout6);


        vboxLayout2->addWidget(ui_groupBoxOverwritePolicy);


        vboxLayout1->addLayout(vboxLayout2);

        ui_tabWidgetMain->addTab(ui_tabGeneral, QString());
        ui_tabFormatting = new QWidget();
        ui_tabFormatting->setObjectName("ui_tabFormatting");
        gridLayout = new QGridLayout(ui_tabFormatting);
        gridLayout->setObjectName("gridLayout");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        ui_groupBoxComment = new QGroupBox(ui_tabFormatting);
        ui_groupBoxComment->setObjectName("ui_groupBoxComment");
        vboxLayout7 = new QVBoxLayout(ui_groupBoxComment);
        vboxLayout7->setObjectName("vboxLayout7");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        ui_forceDoc = new QCheckBox(ui_groupBoxComment);
        ui_forceDoc->setObjectName("ui_forceDoc");

        verticalLayout->addWidget(ui_forceDoc);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        ui_textLabelSectionComments = new QLabel(ui_groupBoxComment);
        ui_textLabelSectionComments->setObjectName("ui_textLabelSectionComments");

        horizontalLayout_2->addWidget(ui_textLabelSectionComments);

        ui_writeSectionComments = new QComboBox(ui_groupBoxComment);
        ui_writeSectionComments->addItem(QString());
        ui_writeSectionComments->addItem(QString());
        ui_writeSectionComments->addItem(QString());
        ui_writeSectionComments->setObjectName("ui_writeSectionComments");

        horizontalLayout_2->addWidget(ui_writeSectionComments);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);


        vboxLayout7->addLayout(verticalLayout);


        gridLayout1->addWidget(ui_groupBoxComment, 0, 0, 1, 1);

        ui_groupBoxLines = new QGroupBox(ui_tabFormatting);
        ui_groupBoxLines->setObjectName("ui_groupBoxLines");
        vboxLayout8 = new QVBoxLayout(ui_groupBoxLines);
        vboxLayout8->setObjectName("vboxLayout8");
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        ui_textLabelType = new QLabel(ui_groupBoxLines);
        ui_textLabelType->setObjectName("ui_textLabelType");
        ui_textLabelType->setWordWrap(false);

        hboxLayout2->addWidget(ui_textLabelType);

        ui_SelectIndentationTypeBox = new KComboBox(ui_groupBoxLines);
        ui_SelectIndentationTypeBox->addItem(QString());
        ui_SelectIndentationTypeBox->addItem(QString());
        ui_SelectIndentationTypeBox->addItem(QString());
        ui_SelectIndentationTypeBox->setObjectName("ui_SelectIndentationTypeBox");

        hboxLayout2->addWidget(ui_SelectIndentationTypeBox);


        vboxLayout8->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        ui_textLabelAmount = new QLabel(ui_groupBoxLines);
        ui_textLabelAmount->setObjectName("ui_textLabelAmount");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(ui_textLabelAmount->sizePolicy().hasHeightForWidth());
        ui_textLabelAmount->setSizePolicy(sizePolicy2);
        ui_textLabelAmount->setWordWrap(false);

        hboxLayout3->addWidget(ui_textLabelAmount);

        ui_SelectIndentationNumber = new QSpinBox(ui_groupBoxLines);
        ui_SelectIndentationNumber->setObjectName("ui_SelectIndentationNumber");

        hboxLayout3->addWidget(ui_SelectIndentationNumber);


        vboxLayout8->addLayout(hboxLayout3);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setObjectName("hboxLayout4");
        ui_textLabelStyle = new QLabel(ui_groupBoxLines);
        ui_textLabelStyle->setObjectName("ui_textLabelStyle");
        ui_textLabelStyle->setWordWrap(false);

        hboxLayout4->addWidget(ui_textLabelStyle);

        ui_SelectEndLineCharsBox = new KComboBox(ui_groupBoxLines);
        ui_SelectEndLineCharsBox->addItem(QString());
        ui_SelectEndLineCharsBox->addItem(QString());
        ui_SelectEndLineCharsBox->addItem(QString());
        ui_SelectEndLineCharsBox->setObjectName("ui_SelectEndLineCharsBox");

        hboxLayout4->addWidget(ui_SelectEndLineCharsBox);


        vboxLayout8->addLayout(hboxLayout4);


        gridLayout1->addWidget(ui_groupBoxLines, 1, 0, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);

        ui_tabWidgetMain->addTab(ui_tabFormatting, QString());

        vboxLayout->addWidget(ui_tabWidgetMain);


        retranslateUi(CodeGenOptionsPage);

        ui_tabWidgetMain->setCurrentIndex(1);
        ui_writeSectionComments->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CodeGenOptionsPage);
    } // setupUi

    void retranslateUi(QWidget *CodeGenOptionsPage)
    {
        CodeGenOptionsPage->setWindowTitle(tr2i18n("Code Generation Options", nullptr));
        ui_groupBoxLanguage->setTitle(tr2i18n("Language", nullptr));
        ui_groupBoxFolders->setTitle(tr2i18n("Folders", nullptr));
        ui_textLabelFolder->setText(tr2i18n("Write all generated files to folder:", nullptr));
#if QT_CONFIG(whatsthis)
        ui_outputDir->setWhatsThis(tr2i18n("Files generated by Code Generator will be written to this folder", nullptr));
#endif // QT_CONFIG(whatsthis)
        ui_browseOutput->setText(tr2i18n("Bro&wse...", nullptr));
        ui_includeHeadings->setText(tr2i18n("&Include heading files from folder:", nullptr));
#if QT_CONFIG(whatsthis)
        ui_headingsDir->setWhatsThis(tr2i18n("Files in this folder will be used as heading files in the generated code", nullptr));
#endif // QT_CONFIG(whatsthis)
        ui_browseHeadings->setText(tr2i18n("B&rowse...", nullptr));
        ui_groupBoxOverwritePolicy->setTitle(tr2i18n("Overwrite Policy", nullptr));
        ui_textLabelOverwritePolicy->setText(tr2i18n("If a file with the same name as the name code \n"
"generator wants to use as output file already exists:", nullptr));
#if QT_CONFIG(whatsthis)
        ui_radioButtonOverwrite->setWhatsThis(tr2i18n("Overwrite existing files if they exist in the destination folder", nullptr));
#endif // QT_CONFIG(whatsthis)
        ui_radioButtonOverwrite->setText(tr2i18n("O&verwrite", nullptr));
#if QT_CONFIG(whatsthis)
        ui_radioButtonAsk->setWhatsThis(tr2i18n("If a file with the same name already exists, ask what to do", nullptr));
#endif // QT_CONFIG(whatsthis)
        ui_radioButtonAsk->setText(tr2i18n("As&k", nullptr));
#if QT_CONFIG(whatsthis)
        ui_radioButtonChangeName->setWhatsThis(tr2i18n("If a file already exists in the destination folder, select a different name to use by adding a suffix to the file name", nullptr));
#endif // QT_CONFIG(whatsthis)
        ui_radioButtonChangeName->setText(tr2i18n("&Use a different name", nullptr));
        ui_tabWidgetMain->setTabText(ui_tabWidgetMain->indexOf(ui_tabGeneral), tr2i18n("General", nullptr));
        ui_groupBoxComment->setTitle(tr2i18n("Comment Verbosity", nullptr));
#if QT_CONFIG(whatsthis)
        ui_forceDoc->setWhatsThis(tr2i18n("Write comments &for class and method documentation even if empty", nullptr));
#endif // QT_CONFIG(whatsthis)
        ui_forceDoc->setText(tr2i18n("&Write documentation comments even if empty", nullptr));
        ui_textLabelSectionComments->setText(tr2i18n("Write section comments:", nullptr));
        ui_writeSectionComments->setItemText(0, tr2i18n("None", nullptr));
        ui_writeSectionComments->setItemText(1, tr2i18n("When section is non empty", nullptr));
        ui_writeSectionComments->setItemText(2, tr2i18n("Always", nullptr));

#if QT_CONFIG(whatsthis)
        ui_writeSectionComments->setWhatsThis(tr2i18n("Writes comments to indicate the different sections (public, private etc) in a class, even if the sections are empty", nullptr));
#endif // QT_CONFIG(whatsthis)
        ui_groupBoxLines->setTitle(tr2i18n("Lines", nullptr));
        ui_textLabelType->setText(tr2i18n("Indentation type:", nullptr));
        ui_SelectIndentationTypeBox->setItemText(0, tr2i18n("No Indentation", nullptr));
        ui_SelectIndentationTypeBox->setItemText(1, tr2i18n("Tab", nullptr));
        ui_SelectIndentationTypeBox->setItemText(2, tr2i18n("Space", nullptr));

        ui_textLabelAmount->setText(tr2i18n("Indentation amount:", nullptr));
        ui_textLabelStyle->setText(tr2i18n("Line ending style:", nullptr));
        ui_SelectEndLineCharsBox->setItemText(0, tr2i18n("*NIX (\"\\n\")", nullptr));
        ui_SelectEndLineCharsBox->setItemText(1, tr2i18n("Windows (\"\\r\\n\")", nullptr));
        ui_SelectEndLineCharsBox->setItemText(2, tr2i18n("Mac (\"\\r\")", nullptr));

        ui_tabWidgetMain->setTabText(ui_tabWidgetMain->indexOf(ui_tabFormatting), tr2i18n("Formatting", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CodeGenOptionsPage: public Ui_CodeGenOptionsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CODEGENOPTIONSPAGE_H

