/********************************************************************************
** Form generated from reading UI file 'exportallviewsdialogbase.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXPORTALLVIEWSDIALOGBASE_H
#define UI_EXPORTALLVIEWSDIALOGBASE_H

#include <KUrlRequester>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_ExportAllViewsDialogBase
{
public:
    QVBoxLayout *verticalLayout;
    QVBoxLayout *vboxLayout;
    QLabel *kURLRequesterLabel;
    KUrlRequester *m_kURL;
    QHBoxLayout *ui_imageTypeLayout;
    QHBoxLayout *ui_imageResolutionLayout;
    QCheckBox *m_useFolders;

    void setupUi(QWidget *ExportAllViewsDialogBase)
    {
        if (ExportAllViewsDialogBase->objectName().isEmpty())
            ExportAllViewsDialogBase->setObjectName("ExportAllViewsDialogBase");
        ExportAllViewsDialogBase->resize(368, 246);
        ExportAllViewsDialogBase->setProperty("sizeGripEnabled", QVariant(true));
        verticalLayout = new QVBoxLayout(ExportAllViewsDialogBase);
        verticalLayout->setObjectName("verticalLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        kURLRequesterLabel = new QLabel(ExportAllViewsDialogBase);
        kURLRequesterLabel->setObjectName("kURLRequesterLabel");
        kURLRequesterLabel->setWordWrap(false);

        vboxLayout->addWidget(kURLRequesterLabel);

        m_kURL = new KUrlRequester(ExportAllViewsDialogBase);
        m_kURL->setObjectName("m_kURL");

        vboxLayout->addWidget(m_kURL);


        verticalLayout->addLayout(vboxLayout);

        ui_imageTypeLayout = new QHBoxLayout();
        ui_imageTypeLayout->setObjectName("ui_imageTypeLayout");

        verticalLayout->addLayout(ui_imageTypeLayout);

        ui_imageResolutionLayout = new QHBoxLayout();
        ui_imageResolutionLayout->setObjectName("ui_imageResolutionLayout");

        verticalLayout->addLayout(ui_imageResolutionLayout);

        m_useFolders = new QCheckBox(ExportAllViewsDialogBase);
        m_useFolders->setObjectName("m_useFolders");

        verticalLayout->addWidget(m_useFolders);

#if QT_CONFIG(shortcut)
        kURLRequesterLabel->setBuddy(m_kURL);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ExportAllViewsDialogBase);

        QMetaObject::connectSlotsByName(ExportAllViewsDialogBase);
    } // setupUi

    void retranslateUi(QWidget *ExportAllViewsDialogBase)
    {
        ExportAllViewsDialogBase->setWindowTitle(tr2i18n("Export All Views", nullptr));
#if QT_CONFIG(tooltip)
        kURLRequesterLabel->setToolTip(tr2i18n("The base directory used to save the images", nullptr));
#endif // QT_CONFIG(tooltip)
        kURLRequesterLabel->setText(tr2i18n("&Directory to save the diagrams in:", nullptr));
#if QT_CONFIG(tooltip)
        m_kURL->setToolTip(tr2i18n("The base directory used to save the images", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_useFolders->setToolTip(tr2i18n("Create in the target directory the same tree structure used\n"
"in the document to store the views", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_useFolders->setWhatsThis(tr2i18n("The views are stored in folders in the document. The same tree structure used in the document to store the views can be created in the selected base directory with this option.\n"
"Only the folders made by the user are created in the base directory (Logical view, use case view and so on are not created).", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_useFolders->setText(tr2i18n("Use &folders", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ExportAllViewsDialogBase: public Ui_ExportAllViewsDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXPORTALLVIEWSDIALOGBASE_H

