/****************************************************************************
** Meta object code from reading C++ file 'umlwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.90/umbrello/umlwidgets/umlwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'umlwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9UMLWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto UMLWidget::qt_create_metaobjectdata<qt_meta_tag_ZN9UMLWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UMLWidget",
        "sigWidgetMoved",
        "",
        "Uml::ID::Type",
        "id",
        "updateWidget",
        "slotMenuSelection",
        "QAction*",
        "action",
        "slotWidgetMoved",
        "slotFillColorChanged",
        "viewID",
        "slotLineColorChanged",
        "slotTextColorChanged",
        "slotLineWidthChanged",
        "slotSnapToGrid"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigWidgetMoved'
        QtMocHelpers::SignalData<void(Uml::ID::Type)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'updateWidget'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMenuSelection'
        QtMocHelpers::SlotData<void(QAction *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'slotWidgetMoved'
        QtMocHelpers::SlotData<void(Uml::ID::Type)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotFillColorChanged'
        QtMocHelpers::SlotData<void(Uml::ID::Type)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 },
        }}),
        // Slot 'slotLineColorChanged'
        QtMocHelpers::SlotData<void(Uml::ID::Type)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 },
        }}),
        // Slot 'slotTextColorChanged'
        QtMocHelpers::SlotData<void(Uml::ID::Type)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 },
        }}),
        // Slot 'slotLineWidthChanged'
        QtMocHelpers::SlotData<void(Uml::ID::Type)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 },
        }}),
        // Slot 'slotSnapToGrid'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UMLWidget, qt_meta_tag_ZN9UMLWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UMLWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<WidgetBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UMLWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UMLWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9UMLWidgetE_t>.metaTypes,
    nullptr
} };

void UMLWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UMLWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigWidgetMoved((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 1: _t->updateWidget(); break;
        case 2: _t->slotMenuSelection((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 3: _t->slotWidgetMoved((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 4: _t->slotFillColorChanged((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 5: _t->slotLineColorChanged((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 6: _t->slotTextColorChanged((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 7: _t->slotLineWidthChanged((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 8: _t->slotSnapToGrid(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UMLWidget::*)(Uml::ID::Type )>(_a, &UMLWidget::sigWidgetMoved, 0))
            return;
    }
}

const QMetaObject *UMLWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UMLWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UMLWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DiagramProxyWidget"))
        return static_cast< DiagramProxyWidget*>(this);
    return WidgetBase::qt_metacast(_clname);
}

int UMLWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WidgetBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void UMLWidget::sigWidgetMoved(Uml::ID::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
