/****************************************************************************
** Meta object code from reading C++ file 'umlscene.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.90/umbrello/umlscene.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'umlscene.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8UMLSceneE_t {};
} // unnamed namespace

template <> constexpr inline auto UMLScene::qt_create_metaobjectdata<qt_meta_tag_ZN8UMLSceneE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UMLScene",
        "sigResetToolBar",
        "",
        "sigFillColorChanged",
        "Uml::ID::Type",
        "sigGridColorChanged",
        "sigLineColorChanged",
        "sigTextColorChanged",
        "sigLineWidthChanged",
        "sigSnapToGridToggled",
        "sigSnapComponentSizeToGridToggled",
        "sigShowGridToggled",
        "sigAssociationRemoved",
        "AssociationWidget*",
        "sigWidgetRemoved",
        "UMLWidget*",
        "slotToolBarChanged",
        "c",
        "slotObjectCreated",
        "UMLObject*",
        "o",
        "slotObjectRemoved",
        "slotMenuSelection",
        "QAction*",
        "action",
        "slotActivate",
        "slotCutSuccessful",
        "slotShowView",
        "alignLeft",
        "alignRight",
        "alignTop",
        "alignBottom",
        "alignVerticalMiddle",
        "alignHorizontalMiddle",
        "alignVerticalDistribute",
        "alignHorizontalDistribute"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigResetToolBar'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigFillColorChanged'
        QtMocHelpers::SignalData<void(Uml::ID::Type)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'sigGridColorChanged'
        QtMocHelpers::SignalData<void(Uml::ID::Type)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'sigLineColorChanged'
        QtMocHelpers::SignalData<void(Uml::ID::Type)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'sigTextColorChanged'
        QtMocHelpers::SignalData<void(Uml::ID::Type)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'sigLineWidthChanged'
        QtMocHelpers::SignalData<void(Uml::ID::Type)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'sigSnapToGridToggled'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'sigSnapComponentSizeToGridToggled'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'sigShowGridToggled'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'sigAssociationRemoved'
        QtMocHelpers::SignalData<void(AssociationWidget *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Signal 'sigWidgetRemoved'
        QtMocHelpers::SignalData<void(UMLWidget *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Slot 'slotToolBarChanged'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'slotObjectCreated'
        QtMocHelpers::SlotData<void(UMLObject *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'slotObjectRemoved'
        QtMocHelpers::SlotData<void(UMLObject *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'slotMenuSelection'
        QtMocHelpers::SlotData<void(QAction *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'slotActivate'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCutSuccessful'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowView'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alignLeft'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alignRight'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alignTop'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alignBottom'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alignVerticalMiddle'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alignHorizontalMiddle'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alignVerticalDistribute'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alignHorizontalDistribute'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UMLScene, qt_meta_tag_ZN8UMLSceneE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UMLScene::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsScene::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8UMLSceneE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8UMLSceneE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8UMLSceneE_t>.metaTypes,
    nullptr
} };

void UMLScene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UMLScene *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigResetToolBar(); break;
        case 1: _t->sigFillColorChanged((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 2: _t->sigGridColorChanged((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 3: _t->sigLineColorChanged((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 4: _t->sigTextColorChanged((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 5: _t->sigLineWidthChanged((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 6: _t->sigSnapToGridToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->sigSnapComponentSizeToGridToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->sigShowGridToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->sigAssociationRemoved((*reinterpret_cast<std::add_pointer_t<AssociationWidget*>>(_a[1]))); break;
        case 10: _t->sigWidgetRemoved((*reinterpret_cast<std::add_pointer_t<UMLWidget*>>(_a[1]))); break;
        case 11: _t->slotToolBarChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->slotObjectCreated((*reinterpret_cast<std::add_pointer_t<UMLObject*>>(_a[1]))); break;
        case 13: _t->slotObjectRemoved((*reinterpret_cast<std::add_pointer_t<UMLObject*>>(_a[1]))); break;
        case 14: _t->slotMenuSelection((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 15: _t->slotActivate(); break;
        case 16: _t->slotCutSuccessful(); break;
        case 17: _t->slotShowView(); break;
        case 18: _t->alignLeft(); break;
        case 19: _t->alignRight(); break;
        case 20: _t->alignTop(); break;
        case 21: _t->alignBottom(); break;
        case 22: _t->alignVerticalMiddle(); break;
        case 23: _t->alignHorizontalMiddle(); break;
        case 24: _t->alignVerticalDistribute(); break;
        case 25: _t->alignHorizontalDistribute(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLWidget* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLObject* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLObject* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)()>(_a, &UMLScene::sigResetToolBar, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(Uml::ID::Type )>(_a, &UMLScene::sigFillColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(Uml::ID::Type )>(_a, &UMLScene::sigGridColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(Uml::ID::Type )>(_a, &UMLScene::sigLineColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(Uml::ID::Type )>(_a, &UMLScene::sigTextColorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(Uml::ID::Type )>(_a, &UMLScene::sigLineWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(bool )>(_a, &UMLScene::sigSnapToGridToggled, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(bool )>(_a, &UMLScene::sigSnapComponentSizeToGridToggled, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(bool )>(_a, &UMLScene::sigShowGridToggled, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(AssociationWidget * )>(_a, &UMLScene::sigAssociationRemoved, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UMLScene::*)(UMLWidget * )>(_a, &UMLScene::sigWidgetRemoved, 10))
            return;
    }
}

const QMetaObject *UMLScene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UMLScene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8UMLSceneE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int UMLScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void UMLScene::sigResetToolBar()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UMLScene::sigFillColorChanged(Uml::ID::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UMLScene::sigGridColorChanged(Uml::ID::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UMLScene::sigLineColorChanged(Uml::ID::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UMLScene::sigTextColorChanged(Uml::ID::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void UMLScene::sigLineWidthChanged(Uml::ID::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void UMLScene::sigSnapToGridToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void UMLScene::sigSnapComponentSizeToGridToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void UMLScene::sigShowGridToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void UMLScene::sigAssociationRemoved(AssociationWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void UMLScene::sigWidgetRemoved(UMLWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
