/********************************************************************************
** Form generated from reading UI file 'codeimpstatuspage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CODEIMPSTATUSPAGE_H
#define UI_CODEIMPSTATUSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CodeImpStatusPage
{
public:
    QVBoxLayout *verticalLayout_3;
    QTabWidget *ui_tabWidget;
    QWidget *ui_tabStatus;
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *verticalLayout;
    QTableWidget *ui_tableWidgetStatus;
    QGridLayout *gridLayout_3;
    QPushButton *ui_pushButtonStart;
    QPushButton *ui_pushButtonStop;
    QWidget *ui_tabLogger;
    QVBoxLayout *verticalLayout_5;
    QVBoxLayout *verticalLayout_2;
    QTextEdit *ui_textEditLogger;
    QGridLayout *gridLayout_4;
    QPushButton *ui_pushButtonClear;
    QPushButton *ui_pushButtonExport;

    void setupUi(QWidget *CodeImpStatusPage)
    {
        if (CodeImpStatusPage->objectName().isEmpty())
            CodeImpStatusPage->setObjectName("CodeImpStatusPage");
        CodeImpStatusPage->resize(500, 530);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CodeImpStatusPage->sizePolicy().hasHeightForWidth());
        CodeImpStatusPage->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(CodeImpStatusPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        ui_tabWidget = new QTabWidget(CodeImpStatusPage);
        ui_tabWidget->setObjectName("ui_tabWidget");
        sizePolicy.setHeightForWidth(ui_tabWidget->sizePolicy().hasHeightForWidth());
        ui_tabWidget->setSizePolicy(sizePolicy);
        ui_tabStatus = new QWidget();
        ui_tabStatus->setObjectName("ui_tabStatus");
        verticalLayout_4 = new QVBoxLayout(ui_tabStatus);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        ui_tableWidgetStatus = new QTableWidget(ui_tabStatus);
        if (ui_tableWidgetStatus->columnCount() < 3)
            ui_tableWidgetStatus->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        ui_tableWidgetStatus->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        ui_tableWidgetStatus->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        ui_tableWidgetStatus->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        ui_tableWidgetStatus->setObjectName("ui_tableWidgetStatus");
        sizePolicy.setHeightForWidth(ui_tableWidgetStatus->sizePolicy().hasHeightForWidth());
        ui_tableWidgetStatus->setSizePolicy(sizePolicy);
        ui_tableWidgetStatus->setAlternatingRowColors(true);
        ui_tableWidgetStatus->setColumnCount(3);

        verticalLayout->addWidget(ui_tableWidgetStatus);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        ui_pushButtonStart = new QPushButton(ui_tabStatus);
        ui_pushButtonStart->setObjectName("ui_pushButtonStart");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ui_pushButtonStart->sizePolicy().hasHeightForWidth());
        ui_pushButtonStart->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(ui_pushButtonStart, 0, 0, 1, 1);

        ui_pushButtonStop = new QPushButton(ui_tabStatus);
        ui_pushButtonStop->setObjectName("ui_pushButtonStop");
        ui_pushButtonStop->setMinimumSize(QSize(80, 0));
        ui_pushButtonStop->setMaximumSize(QSize(80, 16777215));

        gridLayout_3->addWidget(ui_pushButtonStop, 0, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_3);


        verticalLayout_4->addLayout(verticalLayout);

        ui_tabWidget->addTab(ui_tabStatus, QString());
        ui_tabLogger = new QWidget();
        ui_tabLogger->setObjectName("ui_tabLogger");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(ui_tabLogger->sizePolicy().hasHeightForWidth());
        ui_tabLogger->setSizePolicy(sizePolicy2);
        verticalLayout_5 = new QVBoxLayout(ui_tabLogger);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        ui_textEditLogger = new QTextEdit(ui_tabLogger);
        ui_textEditLogger->setObjectName("ui_textEditLogger");
        sizePolicy.setHeightForWidth(ui_textEditLogger->sizePolicy().hasHeightForWidth());
        ui_textEditLogger->setSizePolicy(sizePolicy);

        verticalLayout_2->addWidget(ui_textEditLogger);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        ui_pushButtonClear = new QPushButton(ui_tabLogger);
        ui_pushButtonClear->setObjectName("ui_pushButtonClear");
        sizePolicy1.setHeightForWidth(ui_pushButtonClear->sizePolicy().hasHeightForWidth());
        ui_pushButtonClear->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(ui_pushButtonClear, 0, 0, 1, 1);

        ui_pushButtonExport = new QPushButton(ui_tabLogger);
        ui_pushButtonExport->setObjectName("ui_pushButtonExport");
        sizePolicy1.setHeightForWidth(ui_pushButtonExport->sizePolicy().hasHeightForWidth());
        ui_pushButtonExport->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(ui_pushButtonExport, 0, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_4);


        verticalLayout_5->addLayout(verticalLayout_2);

        ui_tabWidget->addTab(ui_tabLogger, QString());

        verticalLayout_3->addWidget(ui_tabWidget);


        retranslateUi(CodeImpStatusPage);

        ui_tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CodeImpStatusPage);
    } // setupUi

    void retranslateUi(QWidget *CodeImpStatusPage)
    {
        QTableWidgetItem *___qtablewidgetitem = ui_tableWidgetStatus->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Class", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = ui_tableWidgetStatus->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Status", nullptr));
        ui_pushButtonStart->setText(tr2i18n("Start import", nullptr));
        ui_pushButtonStop->setText(tr2i18n("Stop", nullptr));
        ui_tabWidget->setTabText(ui_tabWidget->indexOf(ui_tabStatus), tr2i18n("Import Status", nullptr));
        ui_pushButtonClear->setText(tr2i18n("Clear", nullptr));
        ui_pushButtonExport->setText(tr2i18n("Export...", nullptr));
        ui_tabWidget->setTabText(ui_tabWidget->indexOf(ui_tabLogger), tr2i18n("Logger", nullptr));
        (void)CodeImpStatusPage;
    } // retranslateUi

};

namespace Ui {
    class CodeImpStatusPage: public Ui_CodeImpStatusPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CODEIMPSTATUSPAGE_H

