/********************************************************************************
** Form generated from reading UI file 'umlinstanceattributedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UMLINSTANCEATTRIBUTEDIALOG_H
#define UI_UMLINSTANCEATTRIBUTEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_UMLInstanceAttributeDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QLineEdit *valueLE;
    QLineEdit *nameLE;

    void setupUi(QWidget *UMLInstanceAttributeDialog)
    {
        if (UMLInstanceAttributeDialog->objectName().isEmpty())
            UMLInstanceAttributeDialog->setObjectName("UMLInstanceAttributeDialog");
        UMLInstanceAttributeDialog->resize(200, 100);
        gridLayout = new QGridLayout(UMLInstanceAttributeDialog);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(UMLInstanceAttributeDialog);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label, 0, 0, 1, 2);

        label_2 = new QLabel(UMLInstanceAttributeDialog);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        label_3 = new QLabel(UMLInstanceAttributeDialog);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        valueLE = new QLineEdit(UMLInstanceAttributeDialog);
        valueLE->setObjectName("valueLE");

        gridLayout->addWidget(valueLE, 2, 1, 1, 1);

        nameLE = new QLineEdit(UMLInstanceAttributeDialog);
        nameLE->setObjectName("nameLE");

        gridLayout->addWidget(nameLE, 1, 1, 1, 1);


        retranslateUi(UMLInstanceAttributeDialog);

        QMetaObject::connectSlotsByName(UMLInstanceAttributeDialog);
    } // setupUi

    void retranslateUi(QWidget *UMLInstanceAttributeDialog)
    {
        label->setText(tr2i18n("General Properties", nullptr));
        label_2->setText(tr2i18n("Attribute Name:", nullptr));
        label_3->setText(tr2i18n("Value:", nullptr));
        (void)UMLInstanceAttributeDialog;
    } // retranslateUi

};

namespace Ui {
    class UMLInstanceAttributeDialog: public Ui_UMLInstanceAttributeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UMLINSTANCEATTRIBUTEDIALOG_H

